;;; init-custom-test.el --- Load init- and custom-file successive

;; Author: Andreas Rhler <andreas.roehler@online.de>
;; Keywords: lisp

;; This file is free software; you can redistribute it and/or modify
;; it under the terms of the GNU General Public License as published by
;; the Free Software Foundation; either version 3, or (at your option)
;; any later version.

;; This file is distributed in the hope that it will be useful,
;; but WITHOUT ANY WARRANTY; without even the implied warranty of
;; MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
;; GNU General Public License for more details.

;; You should have received a copy of the GNU General Public License
;; along with GNU Emacs; see the file COPYING.  If not, write to
;; the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
;; Boston, MA 02110-1301, USA.

;;; Commentary:

;; Load init- and custom-file successive. Employ one or
;; more functions at every step, watch the results in
;; order to find some error. `init-check-function'
;; `wcp-bol' delivered with this file was used to check
;; for char 2028 versus char 32; given here as an
;; example.

;;; Code: 

(setq init-check-function 'wcp-bol)
(setq custom-check-function 'wcp-bol)
(setq init-test-delay 1)
(setq custom-test-delay 1)
;; provide for use of alternative init-files 
(setq init-test-file "~/.gnu-emacs-all-cvs")
(setq custom-test-file "~/.gnu-emacs-cvs-custom")
(setq init-custom-test-dummy-file "~/my-test-file.el")


(defun wcp-bol ()
  "Yanks into buffer and reports `what-cursor-position' at
`beginning-of-line'.
 Used to check for char 2028 versus char 32. "
  (interactive)
  (find-file init-custom-test-dummy-file)
  (erase-buffer)
  (yank)
  (beginning-of-line)
  (what-cursor-position)
  (sit-for init-test-delay))

(defun init-test ()
  " "
  (interactive)
  (find-file init-test-file)
  (goto-char (point-min))
  (push-mark) 
  (let ((this-buf (current-buffer))) 
    (while (not (eobp))
      (< (line-end-position) (point-max)) 
      (end-of-defun)
      (what-cursor-position)
      (sit-for init-test-delay)
      (eval-region (mark) (point))
      (push-mark)
      (save-excursion 
	(funcall init-check-function)))))

(defun custom-test ()
  "Evaluate custom-set variables successive. "
  (interactive "*")
  (find-file custom-test-file)
  (goto-char (point-min))
  (end-of-defun)
  (skip-chars-backward " \t\r\n\f")
  (narrow-to-region (point-min) (point)) 
  (forward-char -1)
  (let ((end (point)))
    (when (looking-back ")")
      (split-line))
    (beginning-of-defun)
    (down-list)
    (while (< (line-end-position) end)
      (forward-list)
      (insert ")")
      (eval-region (point-min) (point))
      (save-excursion 
      (funcall custom-check-function))
      (switch-to-buffer (current-buffer))
      (what-cursor-position)
      (sit-for custom-test-delay) 
      (backward-delete-char 1)))) 
 
;; (defconst init-custom-test-version "1.0" 
;;   "Version number of this init-custom-test")
;; 
;; (defun init-custom-test-version (&optional ispec) 
;;   "Print and/or return version of init-custom-test"
;;   (interactive "p")
;;   (when ispec
;;     (message "%s" init-custom-test-version))
;;   init-custom-test-version)

(provide 'init-custom-test)
;;; init-custom-test.el ends here
